

# -- snippet for {numpy|pandas}_cloud testing -- #
from test_util.util import CloudArrayTest
from test_util.util import start_if_not_running, stop_if_running

def setup_function(function):
    start_if_not_running()

def teardown_function(function):
    stop_if_running()

# TODO: use mock.patch() instead of the code below
from pandas.util import testing
def setup_module():
    global old_assert_series_equal
    old_assert_series_equal = testing.assert_series_equal
    def assert_series_equal(*args, **kwargs):
        kwargs['check_series_type'] = False
        return old_assert_series_equal(*args, **kwargs)
    testing.assert_series_equal = assert_series_equal

def teardown_module():
    global old_assert_series_equal
    testing.assert_series_equal = old_assert_series_equal

# -- end {numpy|pandas}_cloud snippet -- #
import numpy_cloud as np
import pytest

from pandas_cloud._libs.tslib import iNaT

from pandas_cloud.core.dtypes.dtypes import PeriodDtype

import pandas_cloud as pd
from pandas_cloud.core.arrays import PeriodArray
from pandas_cloud.tests.extension import base


@pytest.fixture
def dtype():
    return PeriodDtype(freq='D')


@pytest.fixture
def data(dtype):
    return PeriodArray(np.arange(1970, 2070), freq=dtype.freq)


@pytest.fixture
def data_for_sorting(dtype):
    return PeriodArray([2018, 2019, 2017], freq=dtype.freq)


@pytest.fixture
def data_missing(dtype):
    return PeriodArray([iNaT, 2017], freq=dtype.freq)


@pytest.fixture
def data_missing_for_sorting(dtype):
    return PeriodArray([2018, iNaT, 2017], freq=dtype.freq)


@pytest.fixture
def data_for_grouping(dtype):
    B = 2018
    NA = iNaT
    A = 2017
    C = 2019
    return PeriodArray([B, B, NA, NA, A, A, B, C], freq=dtype.freq)


@pytest.fixture
def na_value():
    return pd.NaT


class BasePeriodTests(object):
    pass


class TestPeriodDtype(CloudArrayTest, BasePeriodTests, base.BaseDtypeTests):
    pass


class TestConstructors(CloudArrayTest, BasePeriodTests, base.BaseConstructorsTests):
    pass


class TestGetitem(CloudArrayTest, BasePeriodTests, base.BaseGetitemTests):
    pass


class TestMethods(CloudArrayTest, BasePeriodTests, base.BaseMethodsTests):

    def test_combine_add(self, data_repeated):
        # Period + Period is not defined.
        pass


class TestInterface(CloudArrayTest, BasePeriodTests, base.BaseInterfaceTests):

    pass


class TestArithmeticOps(CloudArrayTest, BasePeriodTests, base.BaseArithmeticOpsTests):
    implements = {'__sub__', '__rsub__'}

    def test_arith_series_with_scalar(self, data, all_arithmetic_operators):
        # we implement substitution...
        if all_arithmetic_operators in self.implements:
            s = pd.Series(data)
            self.check_opname(s, all_arithmetic_operators, s.iloc[0],
                              exc=None)
        else:
            # ... but not the rest.
            super(TestArithmeticOps, self).test_arith_series_with_scalar(
                data, all_arithmetic_operators
            )

    def test_arith_series_with_array(self, data, all_arithmetic_operators):
        if all_arithmetic_operators in self.implements:
            s = pd.Series(data)
            self.check_opname(s, all_arithmetic_operators, s.iloc[0],
                              exc=None)
        else:
            # ... but not the rest.
            super(TestArithmeticOps, self).test_arith_series_with_scalar(
                data, all_arithmetic_operators
            )

    def _check_divmod_op(self, s, op, other, exc=NotImplementedError):
        super(TestArithmeticOps, self)._check_divmod_op(
            s, op, other, exc=TypeError
        )

    def test_add_series_with_extension_array(self, data):
        # we don't implement + for Period
        s = pd.Series(data)
        msg = (r"unsupported operand type\(s\) for \+: "
               r"\'PeriodArray\' and \'PeriodArray\'")
        with pytest.raises(TypeError, match=msg):
            s + data

    def test_error(self):
        pass

    def test_direct_arith_with_series_returns_not_implemented(self, data):
        # Override to use __sub__ instead of __add__
        other = pd.Series(data)
        result = data.__sub__(other)
        assert result is NotImplemented


class TestCasting(CloudArrayTest, BasePeriodTests, base.BaseCastingTests):
    pass


class TestComparisonOps(CloudArrayTest, BasePeriodTests, base.BaseComparisonOpsTests):

    def _compare_other(self, s, data, op_name, other):
        # the base test is not appropriate for us. We raise on comparison
        # with (some) integers, depending on the value.
        pass


class TestMissing(CloudArrayTest, BasePeriodTests, base.BaseMissingTests):
    pass


class TestReshaping(CloudArrayTest, BasePeriodTests, base.BaseReshapingTests):
    pass


class TestSetitem(CloudArrayTest, BasePeriodTests, base.BaseSetitemTests):
    pass


class TestGroupby(CloudArrayTest, BasePeriodTests, base.BaseGroupbyTests):
    pass

HAS_REFCOUNT = False  # No refcount tests for numpy_cloud
